//////////////////////////////////////////////////////////////
//
//  Description	: PDF2TXT DLL library
//  Author	: verypdf.com Inc
//  Version	: Ver 2.8
//  Platform	: Windows95/98/Me/NT/2000
//  Environment	: Visual C++ 6.0
//  Date	: 2002/04/03
//
//  Copyright(C) 2000--2005
//      
//  Contact infomation:
//  Main site,
//  http://www.verypdf.com
//  http://www.verypdf.com/pdf2txt/pdf2txt.htm
//
//  Mirror sites,
//  http://www.toppdf.com
//  http://www.toppdf.com/pdf2txt/pdf2txt.htm
//
//  http://www.globalpdf.com
//  http://www.globalpdf.com/pdf2txt/pdf2txt.htm
//
//  support@verypdf.com;support@toppdf.com
//
//////////////////////////////////////////////////////////////

#ifndef PDF2TXT_H
#define PDF2TXT_H

#ifdef __cplusplus
extern "C"
{
#endif

#ifdef _STATIC_P2TLIB
	#define EXTERN
#else
	#ifdef _USRDLL
		#define EXTERN __declspec(dllexport)
	#else
		#define EXTERN
	#endif
#endif

//////////////////////////////////////////////
//1.int PDF2TXT(char *szPDFName,char *szTXTName)
//Description:
//	Convert PDF file to Text file.
//
//Parameters:
//	szPDFName   : Input PDF file name
//	szTXTName   : Output Text file name
//
//Return value:
//	1 : successed
//	0 : failed
//////////////////////////////////////////////
EXTERN 
int __stdcall PDF2TXT(char *szPDFName,char *szTXTName);

//////////////////////////////////////////////
//2.int SetTXTFormat(int bFormatTXTFile)
//Description:
//        Set text format in generated TXT file.
//
//Parameters:
//        bFormatTXTFile : 1 indicate keep text format
//                       : 0 indicate remove text format
//
//Return value:
//        Return previous flag.
//////////////////////////////////////////////
EXTERN 
int __stdcall SetTXTFormat(int _bFormatTXTFile);

//////////////////////////////////////////////
//3.int SetZoomRatio(int iZoomRatio)
//Description:
//        Set PDF scale options, default is 100, range from 1 to 200.
//
//Parameters:
//        iZoomRatio : scale ratio, date range from 1 to 200
//
//Return value:
//        Return previous scale ratio.
//////////////////////////////////////////////
EXTERN 
int __stdcall SetZoomRatio(int _iZoomRatio);

//////////////////////////////////////////////
//4.void SetPageSeparator(char *pszPageSymbol)
//Description:
//        Set page separator.
//
//Parameters:
//        pszPageSymbol: page separator, if pszPageSymbol is NULL, the page separator will 
//be removed from the result text file.
//
//Return value:
//        none.
//////////////////////////////////////////////
EXTERN 
void __stdcall SetPageSeparator(char *pszPageSymbol);

//////////////////////////////////////////////
//5.void SetPageTBMargin(int top, int bottom)
//Description:
//        Set page top and bottom margin, top margin is from top side (0 position) up to "top" 
//value, bottom value indicate distance from top (0 position) up to "bottom" value, the valid 
//region is from "top" up to "bottom".
//
//Parameters:
//        top    : top margin, unit is pixel
//        bottom : the distance from top side, unit is pixel, if top and bottom equal -1, the 
//valid region is entire page.
//
//Return value:
//        none
//////////////////////////////////////////////
EXTERN 
void __stdcall SetPageTBMargin(int top, int bottom);

//////////////////////////////////////////////
//6.void SetOpenResultFile(BOOL IsOpen)
//Description:
//        Whether open the text file after it be created.
//
//Parameters:
//        IsOpen
//             TRUE :  The generated text file will be auto opened after it created.
//             FALSE:  Don't auto open the generated text file.
//
//Return value:
//        none
//////////////////////////////////////////////
EXTERN 
void __stdcall SetOpenResultFile(BOOL IsOpen);

//////////////////////////////////////////////
//7.void SetDeleteBlankLine(BOOL IsDelete)
//Description:
//       Whether delete blank lines from the result text file.
//
//Parameters:
//       IsDelete
//             TRUE : Delete blank lines from the generated text file.
//             FALSE: Don't delete the blank lines.
//
//Return value:
//        none
//////////////////////////////////////////////
EXTERN 
void __stdcall SetDeleteBlankLine(BOOL IsDelete);

//////////////////////////////////////////////
//8.void SetGetDocumentSummary(BOOL IsGetSummary)
//Description:
//       Whether read the document summary from the pdf file.
//
//Parameters:
//       IsGetSummary
//             TRUE : Read document summary from the pdf file.
//             FALSE: Don't read the document summary.
//
//Return value:
//        none
//////////////////////////////////////////////
EXTERN 
void __stdcall SetGetDocumentSummary(BOOL IsGetSummary);

//////////////////////////////////////////////
//9.const char* PDF2TextBuffer(LPCTSTR pdfFile, int *textBufferSize)
//Description:
//       Convert a pdf file to a text buffer.
//
//Parameters:
//       pdfFile        : input pdf filename
//       textBufferSize	: the size of the return buffer
//
//Return value:
//       Point to a text buffer, after you used it, you need use PDF2TextFreeBuffer function to free it.
//////////////////////////////////////////////
EXTERN
const char* __stdcall PDF2TextBuffer(LPSTR pdfFile, int *textBufferSize);

EXTERN
LPCWSTR __stdcall PDF2TextBufferW(LPCWSTR pdfFile, int *textBufferSize);

EXTERN
LPCWSTR __stdcall PDF2TextBufferWEx(LPSTR pdfFile, int *textBufferSize, 
		int iFirstPage,int iLastPage, LPCTSTR ownerPWD,LPCTSTR userPWD,
		LPSTR textEncName, int noPageBreaks);
//////////////////////////////////////////////
//10.const char* PDFBuffer2TextBuffer(const char* pdfBuffer, int pdfBufferSize,int *textBufferSize)
//Description:
//       Convert a pdf buffer to a text buffer.
//
//Parameters:
//       pdfBuffer      : the pdf file contents
//       pdfBufferSize  : the size of the pdfBuffer
//       textBufferSize	: the size of the return buffer
//
//Return value:
//       Point to a text buffer, after you used it, please use PDF2TextFreeBuffer function to free it.
//////////////////////////////////////////////
EXTERN
const char* __stdcall PDFBuffer2TextBuffer(const char* pdfBuffer, int pdfBufferSize,int *textBufferSize);
EXTERN
LPCWSTR __stdcall PDFBuffer2TextBufferW(const char* pdfBuffer, int pdfBufferSize,int *textBufferSize);
EXTERN
LPCWSTR __stdcall PDFBuffer2TextBufferWEx(const char* pdfBuffer, int pdfBufferSize,int *textBufferSize,
										  int iFirstPage,int iLastPage, LPCTSTR ownerPWD,LPCTSTR userPWD,
										  LPSTR textEncName, int noPageBreaks);
//////////////////////////////////////////////
//11.void PDF2TextFreeBuffer(const char* textBuffer)
//Description:
//       Free the text buffer
//
//Parameters:
//       textBuffer : this parameter is returned by PDF2TextBuffer and PDFBuffer2TextBuffer functions
//
//Return value:
//       none.
//////////////////////////////////////////////
EXTERN
void __stdcall PDF2TextFreeBuffer(const char* textBuffer);

EXTERN
void __stdcall PDF2TextFreeBufferW(LPCWSTR textBuffer);
//////////////////////////////////////////////
//12.void __stdcall SetPasswords(const char* userpassword, const char* ownerpassword)
//Description:
//       Set the passwords for the encrypted pdf file
//
//Parameters:
//       userpassword : the user password for the input pdf file
//
//       ownerpassword : the owner password for the input pdf file
//
//Return value:
//       none.
//////////////////////////////////////////////
EXTERN
void __stdcall SetPasswords(const char* userpassword, const char* ownerpassword);

//////////////////////////////////////////////
//13.int SetAutoAddSpace(int m_bAutoAddSpace1)
//Description:
//        Auto add the spaces into the generated TEXT file.
//
//Parameters:
//        m_bAutoAddSpace1 : 1 enable "auto add the spaces"
//                         : 0 disable "auto add the spaces"
//
//Return value:
//        Return previous flag.
//////////////////////////////////////////////
EXTERN 
int __stdcall SetAutoAddSpace(int m_bAutoAddSpace1);

//////////////////////////////////////////////
//14.int SetAutoSupportUnicode(int m_bAutoAddSpace1)
//Description:
//        This function will convert unicode characters to local characters.
//
//Parameters:
//        m_bUnicode : 1 enable map unicode characters to local characters automatically
//                   : 0 disable auto map function, but you may modify the "charmap.txt"
//                       file to manual map these unicode characters
//
//Return value:
//        Return previous flag.
//////////////////////////////////////////////
EXTERN
void __stdcall SetAutoSupportUnicode(BOOL m_bUnicode);

EXTERN
void __stdcall PDF2TextSetTempPath(DWORD nBufferLength,const char *lpBuffer);

EXTERN
void __stdcall SetOutputCombinedBeforeText(BOOL bEnable);

EXTERN
void __stdcall SetOutputCombinedAfterText(BOOL bEnable);

EXTERN
void __stdcall SetOutputNormalText(BOOL bEnable);

EXTERN
int __stdcall PDF2TXTEx2(LPCTSTR lpPDFName, LPCTSTR lpTXTName,int iFirstPage,
		int iLastPage, LPCTSTR ownerPassword,LPCTSTR userPassword,char *textEncNameA,
		int noPageBreaksA);
		
//////////////////////////////////////////////
//int __stdcall PDF2TXTEx(LPCTSTR lpPDFName, LPCTSTR lpTXTName,int nFirstPage,
//		int nLastPage, LPCTSTR ownerPWD,LPCTSTR userPWD);
//Description:
//        This function will convert PDF file to text file with some special options
//
//Parameters:
//        lpPDFName  : set the PDF file name
//        lpTXTName  : set output text file name
//        nFirstPage : first page to convert
//        nLastPage  : last page to convert
//        ownerPWD   : owner password (for encrypted files)
//        userPWD    : user password (for encrypted files)
//
//Return values:
//         0: - Success not found any problem.
//         1: - Couldn't open PDF file, this PDF file maybe contains an open password or be damaged
//         2: - Couldn't open output text file
//        10: - Success with found some embed fonts.
//        11: - Success with have only embed fonts in PDF file.
//        12: - Fail with empty text file such as this PDF is picture scan or PDF have only picture.
//        -1: - Fail with other causes (can not convert to text file)  such as found exception, time out, not enough memory.
//////////////////////////////////////////////		
EXTERN
int __stdcall PDF2TXTEx(LPCTSTR lpPDFName, LPCTSTR lpTXTName,int iFirstPage,
		int iLastPage, LPCTSTR ownerPWD,LPCTSTR userPWD);

EXTERN
void __stdcall PDF2TXTSetLicenseCode(LPCTSTR lpRegCode);

#ifdef __cplusplus
}
#endif

#endif